@@ -163,6 +163,15 @@ options:
       - Name or id of container(s) to use volumes from
     required: True
     type: list
+  state:
+    description:
+      - Check container status
+    required: False
+    type: str
+    choices:
+      - running
+      - exited
+      - paused
 author: Sam Yaple
 '''
 
@@ -291,7 +300,8 @@ class DockerWorker(object):
             self.compare_pid_mode(container_info) or
             self.compare_volumes(container_info) or
             self.compare_volumes_from(container_info) or
-            self.compare_environment(container_info)
+            self.compare_environment(container_info) or
+            self.compare_container_state(container_info)
         )
 
     def compare_ipc_mode(self, container_info):
@@ -300,8 +310,10 @@ class DockerWorker(object):
         if not current_ipc_mode:
             current_ipc_mode = None
 
-        if new_ipc_mode != current_ipc_mode:
+        # only check IPC mode if it is specified
+        if new_ipc_mode is not None and new_ipc_mode != current_ipc_mode:
             return True
+        return False
 
     def compare_cap_add(self, container_info):
         new_cap_add = self.params.get('cap_add', list())
@@ -420,6 +432,12 @@ class DockerWorker(object):
                 if current_env[k] != v:
                     return True
 
+    def compare_container_state(self, container_info):
+        new_state = self.params.get('state')
+        current_state = container_info['State'].get('Status')
+        if new_state != current_state:
+            return True
+
     def parse_image(self):
         full_image = self.params.get('image')
 
@@ -728,7 +746,10 @@ def generate_module():
         name=dict(required=False, type='str'),
         environment=dict(required=False, type='dict'),
         image=dict(required=False, type='str'),
-        ipc_mode=dict(required=False, type='str', choices=['host', '']),
+        ipc_mode=dict(required=False, type='str', choices=['',
+                                                           'host',
+                                                           'private',
+                                                           'shareable']),
         cap_add=dict(required=False, type='list', default=list()),
         security_opt=dict(required=False, type='list', default=list()),
         pid_mode=dict(required=False, type='str', choices=['host', '']),
@@ -742,6 +763,10 @@ def generate_module():
                             'always',
                             'unless-stopped']),
         restart_retries=dict(required=False, type='int', default=10),
+        state=dict(required=False, type='str', default='running',
+                   choices=['running',
+                            'exited',
+                            'paused']),
         tls_verify=dict(required=False, type='bool', default=False),
         tls_cert=dict(required=False, type='str'),
         tls_key=dict(required=False, type='str'),
